function [Res_Output] = fnc_alpha_capacitance(y_i)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function to calculate void fraction, stored energy and
% capacity for given distance betwenn the electrodes
%
% Input parameters: 
%   y_i as constant in mm
%
% Output parameters:
%   Res_Output as matrix: 
%                   Void fraction
%                   W_vapour stored energy of pure vapour 
%                   C_vapour capacitance of pure vapour
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Vapour phase

% 1. Step: Create link between Matlab and Quickfield
%get link to QuickField
qf = actxserver ('QuickField.Application'); 
%get link to the problem
prb = qf.Problems.Item(1);      
%load model
prb.LoadModel;                  
%get link to the model
mdl = prb.Model;    

% 2. Step: Change geometry of model
%select the object to move block/edge/vertex
theEdge_BC_m = mdl.Shapes.get ('LabeledAs','','BC_m',''); % 'Vertex','Edge','Block'
%specify the displacement vector
theVector = qf.PointXY(0 , y_i);
%move the selected Shape
theEdge_BC_m.Move('qfShift', theVector); %Object.Move(qfShift/qfRotation/qfScaling, Vector(x,y)/Double)
%build mesh in the model
mdl.Shapes.BuildMesh();
%save model file
mdl.Save;   
 
% 3. Step Calculate the results
%solve problem
prb.SolveProblem();             
%load results
prb.AnalyzeResults;
%get link to the result
res = prb.Result;               
%open the field window
theFieldWindow = res.GetFieldWindow(1);

% 4. Get Stored Energy of Capacitor:
%get link to the contour
theContour = theFieldWindow.Contour; 
%add block to contour 
theContour.AddBlock1 ('Liquid_l');     
theContour.AddBlock1 ('Liquid_m');
theContour.AddBlock1 ('Liquid_r');    
theContour.AddBlock1 ('Vapour_l');    
theContour.AddBlock1 ('Vapour_m');    
theContour.AddBlock1 ('Vapour_r');
%calculate the integral of desired value
theStoredEnergy_Vapour = res.GetIntegral('qfInt_ElectrostaticEnergy', theContour).Value; %Result.GetIntegral (QfIntegrals, Contour).Quantity
%Delete the contour for new contour     
theContour.DeleteBlock1 ('Liquid_l');     
theContour.DeleteBlock1 ('Liquid_m');
theContour.DeleteBlock1 ('Liquid_r');    
theContour.DeleteBlock1 ('Vapour_l');    
theContour.DeleteBlock1 ('Vapour_m');    
theContour.DeleteBlock1 ('Vapour_r'); 

% 5. Get void fraction:
%Volume of liquid phase
%get link to the contour
theContour = theFieldWindow.Contour; 
%add block to contour 
theContour.AddBlock1 ('Liquid_l');     
theContour.AddBlock1 ('Liquid_m');
theContour.AddBlock1 ('Liquid_r');    
%calculate the integral of desired value
theVolume_Liquid = res.GetIntegral('qfInt_Volume', theContour).Value; %Result.GetIntegral (QfIntegrals, Contour).Quantity
%Delete the contour for new contour     
theContour.DeleteBlock1 ('Liquid_l');     
theContour.DeleteBlock1 ('Liquid_m');
theContour.DeleteBlock1 ('Liquid_r');    
%Volume of vapour phase
%get link to the contour
theContour = theFieldWindow.Contour;
%add block to contour 
theContour.AddBlock1 ('Vapour_l');    
theContour.AddBlock1 ('Vapour_m');    
theContour.AddBlock1 ('Vapour_r');
%calculate the integral of desired value
theVolume_Vapour = res.GetIntegral('qfInt_Volume', theContour).Value; %Result.GetIntegral (QfIntegrals, Contour).Quantity
%Delete the contour for new contour 
theContour.DeleteBlock1 ('Vapour_l');    
theContour.DeleteBlock1 ('Vapour_m');    
theContour.DeleteBlock1 ('Vapour_r'); 

alpha=theVolume_Vapour/(theVolume_Vapour+theVolume_Liquid);

%% Results 

% 7 Create output vector:
% Get voltage of each electrode (only positive values, negative sign is
% neglected) and calculate potential
U_l=prb.Labels ('qfEdge').Item ('E_l').Content.Dirichlet;
U_r=prb.Labels ('qfEdge').Item ('E_r').Content.Dirichlet;
V_lr=abs(U_l-U_r);
% Calculate capacitance using stored energy: C = 2*W/(V)^2
theCapacitance_Vapour=2*theStoredEnergy_Vapour/(V_lr)^2;
% Void fraction | W | C
Res_Output=[alpha , theStoredEnergy_Vapour , theCapacitance_Vapour];

%% Reset model

% 8. Reset geometrical changes
% x_position = absolute values
theVector = qf.PointXY(0, -y_i);
theEdge_BC_m.Move('qfShift', theVector); %Object.Move(qfShift/qfRotation/qfScaling, Vector(x,y)/Double)
%theEdge_E_r.Move('qfShift', theVector);
mdl.Save;
end


