function fnc_set_model(epsilon_r , Names_Blocks , distance, length_electrodes, r_i)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function to change model geometry and data: length of electrodes, distance between
% electrodes, inner radius of pipe, relative permitivitties of liquid and
% vapour phase
%
% Input parameters: 
%   distance as constant: Distance between electrodes in mm
%   length_electrodes as constant: Length of both electrodes in mm
%   r_i as constant: inner radius of pipe in mm
%   epsilon_r.vapour as struct: relative permittivity of vapour phase
%   epsilon_r.liquid as struct: relative permittivity of liquid phase
%   Names_Blocks as cell-struct: label of blocks, DO NOT CHANGE THEIR NAMES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 1. Step: Create link between Matlab and Quickfield
%get link to QuickField
qf = actxserver ('QuickField.Application'); 
%get link to the problem
prb = qf.Problems.Item(1);      
%load model
prb.LoadModel;                  
%get link to the model
mdl = prb.Model;    

% 2. Set electric permittivity of Liquid blocks and vapour blocks
%Liquid blocks
for n_for=1:length(Names_Blocks.Liquid)
    % get desired label
    blocklabels=prb.Labels ('qfBlock');
    blocklab=blocklabels.Item (Names_Blocks.Liquid{n_for});
    % get content of block n_for
    blocklabCnt=blocklab.Content;
    % modify content 
    blocklabCnt.set ('Kxx',false,epsilon_r.liquid); 
    blocklabCnt.set ('Kyy',false,epsilon_r.liquid); 
    % Change modified content of the desired label
    blocklab.Content=blocklabCnt;
    blocklab.DataDoc.Save
end
%Vapour blocks
for n_for=1:length(Names_Blocks.Liquid)
    % get desired label
    blocklabels=prb.Labels ('qfBlock');
    blocklab=blocklabels.Item (Names_Blocks.Vapour{n_for});
    % get content of block n_for
    blocklabCnt=blocklab.Content;
    % modify content 
    blocklabCnt.set ('Kxx',false,epsilon_r.vapour); 
    blocklabCnt.set ('Kyy',false,epsilon_r.vapour); 
    % Change modified content of the desired label
    blocklab.Content=blocklabCnt;
    blocklab.DataDoc.Save
end


% 3. Step: Change geometry of model

%Change radius
Height=mdl.shapes.dimensions.height;
%select the object to move block/edge/vertex
theBlock_Liquid_l = mdl.Shapes.get ('LabeledAs','','','Liquid_l'); % 'Vertex','Edge','Block'
theBlock_Liquid_r = mdl.Shapes.get ('LabeledAs','','','Liquid_r'); % 'Vertex','Edge','Block'
theEdge_BC_m = mdl.Shapes.get ('LabeledAs','','BC_m',''); % 'Vertex','Edge','Block'
%specify the displacement vector
theVector = qf.PointXY(0, r_i-Height);
theVector_BC_m = qf.PointXY(0, -(r_i-Height));
if Height > r_i
    %move BC_m first to avoid any problems
    theEdge_BC_m.Move('qfShift', theVector_BC_m);
    %move the selected Shapes
    theBlock_Liquid_l.Move('qfShift', theVector);
    theBlock_Liquid_r.Move('qfShift', theVector);
elseif Height < r_i
    %move the selected Shapes
    theBlock_Liquid_l.Move('qfShift', theVector);
    theBlock_Liquid_r.Move('qfShift', theVector);
    %move BC_m back to old loaction
    theEdge_BC_m.Move('qfShift', theVector_BC_m);
end


%Change distance and length of electrodes
%select the object to move block/edge/vertex
theBlock_Vapour_m = mdl.Shapes.get ('LabeledAs','','','Vapour_m'); % 'Vertex','Edge','Block'
theBlock_Vapour_r = mdl.Shapes.get ('LabeledAs','','','Vapour_r'); % 'Vertex','Edge','Block'
theEdge_BC_r = mdl.Shapes.get ('LabeledAs','','BC_r',''); % 'Vertex','Edge','Block'
theEdge_E_l = mdl.Shapes.get ('LabeledAs','','E_l',''); % 'Vertex','Edge','Block'
theEdge_E_r = mdl.Shapes.get ('LabeledAs','','E_r',''); % 'Vertex','Edge','Block'
theEdge_Distance = mdl.Shapes.get ('LabeledAs','','Distance',''); % 'Vertex','Edge','Block'
%To avoid any problems move middle and right shapes to the right
theVector_tot = qf.PointXY(2*length_electrodes+distance , 0);
theEdge_BC_r.Move('qfShift', theVector_tot);
theBlock_Vapour_m.Move('qfShift', theVector_tot);
theEdge_Distance.Move('qfShift', theVector_tot);
%Move middle part back to determine size of electrode 1
length_E_l = theEdge_E_l.dimensions.Width;
theVector_E_l = qf.PointXY(length_electrodes-length_E_l , 0);
theBlock_Vapour_m.Move('qfShift', theVector_E_l);
theEdge_Distance.Move('qfShift', theVector_E_l);
%Move right part back to determine size of distance
length_Distance = theEdge_Distance.dimensions.Width;
theVector_Distance = qf.PointXY(distance-length_Distance , 0);
theBlock_Vapour_r.Move('qfShift', theVector_Distance);
theEdge_E_r.Move('qfShift', theVector_Distance);
%Move BC_r back to determine size of distance
length_E_r = theEdge_E_r.dimensions.Width;
theVector_E_r = qf.PointXY(length_electrodes-length_E_r , 0);
theEdge_BC_r.Move('qfShift', theVector_E_r);

%build mesh in the model
mdl.Shapes.BuildMesh();
%save model file
mdl.Save; 


end